# -*- coding: utf-8 -*-

from django import forms
from django.forms import widgets
from django.utils.translation import ugettext_lazy, ugettext

from newsletter_subscriptions.models import Subscription


class SubscriptionForm(forms.ModelForm):
    """
    Subscription base form

    We need to use another field name that 'email' because it cause duplicate
    ids with forms because this subscribe form is on every pages, like contact
    form that already have an email field. Crispy forms does not honor given
    field id on its container
    """
    error_css_class = 'error'
    required_css_class = 'required'

    nl_email = forms.EmailField(
        label=ugettext_lazy('Email'),
        widget=widgets.EmailInput(attrs={'required': ''}),
        required=True
    )
    opt_in = forms.BooleanField(
        label=ugettext_lazy(u'I wish to receive the newsletter'),
        widget=widgets.CheckboxInput(attrs={'required': ''}),
        required=True
    )

    def clean_nl_email(self):
        """
        Get back uniqueness validation for custom field
        """
        nl_email = self.cleaned_data.get('nl_email')
        if nl_email and Subscription.objects.filter(email__iexact=nl_email.strip()).exists():
            error_msg = ugettext(u'This email already subscribed.')
            raise forms.forms.ValidationError(error_msg)
        return nl_email

    def save(self):
        """Save"""
        self.instance.email = self.cleaned_data['nl_email']
        return super(SubscriptionForm, self).save()

    class Meta:
        model = Subscription
        fields = [
            'nl_email',
            'opt_in',
        ]
