# -*- coding: utf-8 -*-

import os
import sys

from paver.easy import task, consume_args, info

try:
    import sett  # noqa
except ImportError:
    pass


def init(env):
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'newsletter_subscriptions_demo.settings')


@task
@consume_args
def robot(ROOT, args):
    dsm = os.environ.get('ROBOT_SETTINGS_MODULE', 'lib.settings')
    info('Using %s as settings', dsm)
    os.environ['DJANGO_SETTINGS_MODULE'] = dsm
    sys.path.append(ROOT.joinpath('tests'))

    import robot
    robot.run_cli(args)


@task
def po():
    from django.core.management import call_command
    call_command('makemessages', no_location=True, ignore=['build', 'dist', '*.egg-info'], locale=['fr', 'en'])


@task
def mo():
    from django.core.management import call_command
    call_command('compilemessages', locale=['en', 'fr'])


def find_version(filename):
    filepath = os.path.join(os.path.dirname(__file__), filename)
    with open(filepath, 'r') as init:
        for line in init:
            if line.startswith('__version__'):
                x, version = line.split('=', 1)
                return version.strip().strip('\'"')
        else:
            raise ValueError('Cannot find the version in {0}'.format(filename))


def parse_requirements(requirements_txt):
    requirements = []
    try:
        with open(requirements_txt, 'r') as f:
            for line in f:
                line = line.strip()
                if line.startswith('#') or not line:
                    continue
                if '://' in line:
                    continue
                if line.startswith('-'):
                    raise ValueError('Unexpected command {0} in {1}'.format(
                        line,
                        requirements_txt,
                    ))

                requirements.append(line)
        return requirements
    except IOError:
        return []


@task
def setup_options():
    import setuptools
    from paver.setuputils import setup
    readme_md = os.path.join(os.path.dirname(__file__), 'README.md')
    with open(readme_md, 'r') as readme_file:
        readme = readme_file.read()

    setup(
        name='newsletter-subscriptions',
        version=find_version('newsletter_subscriptions/__init__.py'),
        description='Newsletter subscription application',
        long_description=readme,
        author='Grégoire ROCHER',
        author_email='gregoire@emencia.com',
        packages=setuptools.find_packages(
            exclude=[
                'tests',
                'newsletter_subscriptions.tests',
                'newsletter_subscriptions.tests.*',
                'newsletter_subscriptions_demo',
                'newsletter_subscriptions_demo.*',
            ],
        ),
        include_package_data=True,
        install_requires=parse_requirements('requirements.txt'),
        zip_safe=False,
    )


if os.path.basename(sys.argv[0]) == 'setup.py':
    setup_options()


try:
    import sett  # noqa
    with open(sett.ROOT.joinpath('localpavement.py'), 'r') as localpavement:
        exec(localpavement.read(), locals(), globals())
except (OSError, IOError, ImportError) as e:
    pass
